summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/pmax/dev/if_le.c6
-rw-r--r--sys/arch/sun3/dev/if_ie.c16
-rw-r--r--sys/arch/vax/if/if_de.c6
-rw-r--r--sys/arch/vax/if/if_qe.c8
4 files changed, 18 insertions, 18 deletions
diff --git a/sys/arch/pmax/dev/if_le.c b/sys/arch/pmax/dev/if_le.c
index 74b080804a7..3b0b7f86cb5 100644
--- a/sys/arch/pmax/dev/if_le.c
+++ b/sys/arch/pmax/dev/if_le.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_le.c,v 1.16 1995/08/13 00:07:17 mycroft Exp $ */
+/* $NetBSD: if_le.c,v 1.17 1995/12/24 02:30:42 mycroft Exp $ */
/*-
* Copyright (c) 1992, 1993
@@ -528,7 +528,7 @@ leinit(unit)
int s;
if ((ifp->if_flags & IFF_RUNNING) == 0) {
- s = splimp();
+ s = splnet();
ifp->if_flags |= IFF_RUNNING;
lereset(unit);
lestart(ifp);
@@ -968,7 +968,7 @@ leioctl(ifp, cmd, data)
volatile struct lereg1 *ler1 = le->sc_r1;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
case SIOCSIFADDR:
diff --git a/sys/arch/vax/if/if_de.c b/sys/arch/vax/if/if_de.c
index d42a45ec242..cf239587ca3 100644
--- a/sys/arch/vax/if/if_de.c
+++ b/sys/arch/vax/if/if_de.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_de.c,v 1.10 1995/12/01 19:37:55 ragge Exp $ */
+/* $NetBSD: if_de.c,v 1.11 1995/12/24 02:30:52 mycroft Exp $ */
/*
* Copyright (c) 1982, 1986, 1989 Regents of the University of California.
@@ -345,7 +345,7 @@ deinit(unit)
}
/* start up the board (rah rah) */
- s = splimp();
+ s = splnet();
ds->ds_rindex = ds->ds_xindex = ds->ds_xfree = ds->ds_nxmit = 0;
ds->ds_if.if_flags |= IFF_RUNNING;
addr->pclow = PCSR0_INTE; /* avoid interlock */
@@ -584,7 +584,7 @@ deioctl(ifp, cmd, data)
{
register struct ifaddr *ifa = (struct ifaddr *)data;
register struct de_softc *ds = decd.cd_devs[ifp->if_unit];
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
diff --git a/sys/arch/vax/if/if_qe.c b/sys/arch/vax/if/if_qe.c
index a468d3011f4..8f44ae74658 100644
--- a/sys/arch/vax/if/if_qe.c
+++ b/sys/arch/vax/if/if_qe.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_qe.c,v 1.7 1995/12/01 19:37:59 ragge Exp $ */
+/* $NetBSD: if_qe.c,v 1.8 1995/12/24 02:30:55 mycroft Exp $ */
/*
* Copyright (c) 1988 Regents of the University of California.
@@ -495,7 +495,7 @@ qeinit(unit)
* Take the interface out of reset, program the vector,
* enable interrupts, and tell the world we are up.
*/
- s = splimp();
+ s = splnet();
addr->qe_vector = sc->qe_intvec;
sc->addr = addr;
addr->qe_csr = QE_RCV_ENABLE | QE_INT_ENABLE | QE_XMIT_INT |
@@ -527,7 +527,7 @@ qestart(ifp)
int buf_addr, len, s;
- s = splimp();
+ s = splnet();
/*
* The deqna doesn't look at anything but the valid bit
* to determine if it should transmit this packet. If you have
@@ -773,7 +773,7 @@ qeioctl(ifp, cmd, data)
{
struct qe_softc *sc = qecd.cd_devs[ifp->if_unit];
struct ifaddr *ifa = (struct ifaddr *)data;
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
diff --git a/sys/arch/sun3/dev/if_ie.c b/sys/arch/sun3/dev/if_ie.c
index 2a4135f607a..10ecdf0e7f1 100644
--- a/sys/arch/sun3/dev/if_ie.c
+++ b/sys/arch/sun3/dev/if_ie.c
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie.c,v 1.5 1995/04/11 06:05:11 mycroft Exp $ */
+/* $NetBSD: if_ie.c,v 1.6 1995/12/24 02:30:48 mycroft Exp $ */
/*-
* Copyright (c) 1993, 1994, 1995 Charles Hannum.
@@ -92,7 +92,7 @@
shall have the I (IE_CMD_INTR) bit set in the command. This way,
when an interrupt arrives at ieintr(), it is immediately possible
to tell what precisely caused it. ANY OTHER command-sending
- routines should run at splimp(), and should post an acknowledgement
+ routines should run at splnet(), and should post an acknowledgement
to every interrupt they generate.
*/
@@ -1084,7 +1084,7 @@ ie_setupram(sc)
volatile struct ie_sys_ctl_block *scb;
int s;
- s = splimp();
+ s = splnet();
scp = sc->scp;
(sc->sc_bzero)((char *) scp, sizeof *scp);
@@ -1124,7 +1124,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
printf("%s: reset\n", sc->sc_dev.dv_xname);
@@ -1191,7 +1191,7 @@ command_and_wait(sc, cmd, pcmd, mask)
/*
* XXX
* I don't think this timeout works on suns.
* we are at splimp() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1413,7 +1413,7 @@ setup_bufs(sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -1447,7 +1447,7 @@ mc_setup(sc, ptr)
* This includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands,
* starting the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -1550,7 +1550,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *) data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -1191,7 +1191,7 @@ command_and_wait(sc, cmd, pcmd, mask)
* XXX
* I don't think this timeout works on suns.
- * we are at splimp() in the loop, and the timeout
+ * we are at splnet() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1447,7 +1447,7 @@ mc_setup(sc, ptr)
* starting the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int